@@ -1,4 +1,6 @@
 #' @include avro_utils.R
+#' @include tables_spark.R
+#' @include utils.R
 NULL
 
 #' Copy an Object into Spark
@@ -36,8 +38,11 @@ NULL
 #'
 #' @examples
 #'
+#' \dontrun{
 #' sc <- spark_connect(master = "spark://HOST:PORT")
 #' sdf_copy_to(sc, iris)
+#'}
+#'
 #' @name sdf_copy_to
 #' @export
 sdf_copy_to <- function(sc,
@@ -113,7 +118,7 @@ sdf_import.default <- function(x,
   )
 
   if (memory && !class(x)[[1]] %in% c("iterator", "list")) {
-    tbl_cache(sc, name)
+    tbl_cache_sdf(sc, name, force = FALSE)
   }
 
   on_connection_updated(sc, name)
@@ -365,7 +370,8 @@ sdf_last_index <- function(x, id = "id") {
 #' approximate quantiles (to some relative error).
 #'
 #' @template roxlate-ml-x
-#' @param column The column for which quantiles should be computed.
+#' @param column The column(s) for which quantiles should be computed.
+#' Multiple columns are only supported in Spark 2.0+.
 #' @param probabilities A numeric vector of probabilities, for
 #'   which quantiles should be computed.
 #' @param relative.error The relative error -- lower values imply more
@@ -378,17 +384,31 @@ sdf_quantile <- function(x,
                          relative.error = 1E-5) {
   sdf <- spark_dataframe(x)
 
+  if (length(column) > 1) {
+    if (package_version(sdf$connection$home_version) <
+        package_version("2.0.0")) {
+      stop("Spark 2.0+ is required when length(column) > 1")
+    }
+  }
+
   nm <-
     names(probabilities) %||%
     paste(signif(probabilities * 100, 3), "%", sep = "")
 
-  column <- cast_string(column)
+  column <- lapply(column, cast_string)
   probabilities <- as.list(as.numeric(probabilities))
   relative.error <- cast_scalar_double(relative.error)
 
   stat <- invoke(sdf, "stat")
   quantiles <- invoke(stat, "approxQuantile", column, probabilities, relative.error)
-  names(quantiles) <- nm
+
+  if (length(column) == 1) {
+    quantiles <- unlist(quantiles)
+    names(quantiles) <- nm
+  } else {
+    names(quantiles) <- column
+    quantiles <- lapply(quantiles, `names<-`, nm)
+  }
 
   quantiles
 }
@@ -657,3 +677,185 @@ sdf_from_avro <- function(x, cols) {
     }
   )
 }
+
+#' Create a Spark dataframe containing all combinations of inputs
+#'
+#' Given one or more R vectors/factors or single-column Spark dataframes,
+#' perform an expand.grid operation on all of them and store the result in
+#' a Spark dataframe
+#'
+#' @param sc The associated Spark connection.
+#' @param ... Each input variable can be either a R vector/factor or a Spark
+#'   dataframe. Unnamed inputs will assume the default names of 'Var1', 'Var2',
+#'   etc in the result, similar to what `expand.grid` does for unnamed inputs.
+#' @param broadcast_vars Indicates which input(s) should be broadcasted to all
+#'   nodes of the Spark cluster during the join process (default: none).
+#' @param memory Boolean; whether the resulting Spark dataframe should be
+#'   cached into memory (default: TRUE)
+#' @param repartition Number of partitions the resulting Spark dataframe should
+#'   have
+#' @param partition_by Vector of column names used for partitioning the
+#'   resulting Spark dataframe, only supported for Spark 2.0+
+#'
+#' @examples
+#'
+#' \dontrun{
+#' sc <- spark_connect(master = "local")
+#' grid_sdf <- sdf_expand_grid(sc, seq(5), rnorm(10), letters)
+#' }
+#'
+#' @export
+sdf_expand_grid <- function(
+                            sc,
+                            ...,
+                            broadcast_vars = NULL,
+                            memory = TRUE,
+                            repartition = NULL,
+                            partition_by = NULL) {
+  if (spark_version(sc) < "2.0.0") {
+    stop("`sdf_expand_grid()` requires Spark 2.0.0 or above")
+  }
+
+  vars <- list(...)
+  if (length(vars) == 0) {
+    invoke(spark_session(sc), "emptyDataFrame") %>% sdf_register()
+  } else {
+    if (is.null(names(vars))) {
+      names(vars) <- rep("", length(vars))
+    }
+    for (i in seq_along(vars)) {
+      var_name <- names(vars[i])
+      if (is.null(var_name) || identical(var_name, "")) {
+        names(vars)[[i]] <- sprintf("Var%d", i)
+      }
+      if (!"tbl_spark" %in% class(vars[[i]])) {
+        vars[[i]] <- sdf_copy_to(
+          sc, data.frame(vars[i]), name = random_string("sdf_expand_grid_tmp")
+        )
+      }
+    }
+    broadcast_vars <- rlang::enexpr(broadcast_vars)
+    if (!rlang::is_null(broadcast_vars)) {
+      broadcast_vars <- broadcast_vars %>%
+        (
+          function(exprs) {
+            if (length(exprs) > 1) {
+              as.list(exprs)[-1]
+            } else {
+              as.list(exprs)[1]
+            }
+          }
+        ) %>%
+          lapply(rlang::as_string) %>%
+          unlist()
+    }
+    for (x in broadcast_vars) {
+      idxes <- which (names(vars) %in% x)
+      if (length(idxes) > 0) {
+        for (idx in idxes) {
+          vars[[idx]] <- sdf_broadcast(vars[[idx]])
+        }
+      } else {
+        warning(
+          sprintf("Broadcast variable '%s'", x),
+          " is not among the list of input variable(s)! It will be ignored."
+        )
+      }
+    }
+
+    vars_ordering <- lapply(vars, colnames) %>% unlist()
+    # reverse ordering of variables so that the 1st variable in the input is the
+    # one varying the fastest, 2nd one varying the 2nd fastest, etc in the cross
+    # join output
+    vars <- rev(vars)
+
+    grid_sdf <- spark_dataframe(vars[[1]])
+    for (i in seq(2, length(vars))) {
+      grid_sdf <- invoke(grid_sdf, "crossJoin", spark_dataframe(vars[[i]]))
+    }
+
+    grid_sdf <- grid_sdf %>%
+      invoke("select", vars_ordering[[1]], as.list(vars_ordering[-1])) %>%
+      sdf_register()
+
+    if (!is.null(repartition) || !is.null(partition_by)) {
+      grid_sdf <- grid_sdf %>% sdf_repartition(repartition, partition_by)
+    }
+
+    if (memory) {
+      invoke(spark_dataframe(grid_sdf), "cache")
+    }
+
+    grid_sdf
+  }
+}
+
+#' Compute the number of records within each partition of a Spark DataFrame
+#'
+#' @template roxlate-ml-x
+#'
+#' @examples
+#'
+#' \dontrun{
+#' library(sparklyr)
+#' sc <- spark_connect(master = "spark://HOST:PORT")
+#' example_sdf <- sdf_len(sc, 100L, repartition = 10L)
+#' example_sdf %>% sdf_partition_sizes() %>% print()
+#'}
+#'
+#' @export
+sdf_partition_sizes <- function(x) {
+  sc <- spark_connection(x)
+
+  rs <- invoke_static(
+    sc,
+    "sparklyr.PartitionUtils",
+    "computePartitionSizes",
+    spark_dataframe(x)
+  )
+
+  # workaround to make CRAN happy
+  partition_index <- NULL
+
+  data.frame(
+    partition_index = lapply(rs, function(p) p[[1]]) %>% unlist(),
+    partition_size = lapply(rs, function(p) p[[2]]) %>% unlist()
+  ) %>%
+    dplyr::arrange(partition_index)
+}
+
+#' Subsetting operator for Spark dataframe
+#'
+#' Susetting operator for Spark dataframe allowing a subset of column(s) to be
+#' selected using syntaxes similar to those supported by R dataframes
+#'
+#' @param x The Spark dataframe
+#' @param i Expression specifying subset of column(s) to include or exclude
+#'   from the result (e.g., `["col1"]`, `[c("col1", "col2")]`, `[1:10]`, `[-1]`,
+#'   `[NULL]`, or `[]`)
+#'
+#' @examples
+#'
+#' \dontrun{
+#' library(sparklyr)
+#' sc <- spark_connect(master = "spark://HOST:PORT")
+#' example_sdf <- copy_to(sc, tibble::tibble(a = 1, b = 2))
+#' example_sdf["a"] %>% print()
+#'}
+#'
+#' @export
+`[.tbl_spark` <- function(x, i) {
+  if (missing(i)) {
+    x
+  } else if (is.null(i)) {
+    x %>%
+      spark_connection() %>%
+      spark_session() %>%
+      invoke("emptyDataFrame")
+  } else {
+    rx <- replicate_colnames(x)
+    cols <- colnames(rx[i])
+
+    x %>>% dplyr::select %@% lapply(cols, as.symbol)
+  }
+}
